@@ -31,7 +31,7 @@ hwe <- function(data, data.type="allele", yates.correct=FALSE, miss.val=0)
      dimnames(allele.freq)[[1]] <- tmp$allele.label
      geno.obs <- as.numeric(names(geno.table))
      geno.len <- length(geno.table)
-     n.genotype <- geno.obs[geno.len]
+     n.genotype <- n.allele * (n.allele + 1) /2
      # nonobserved contributes data
      geno.all <- array(0,n.genotype)
      for(i in 1:geno.len)
@@ -88,7 +88,7 @@ hwe <- function(data, data.type="allele", yates.correct=FALSE, miss.val=0)
   df <- n.genotype - n.allele
   lrt <- 2.0 * lrt
   rho <- sqrt(x2 / n)
-  cat("Pearson x2=",x2,"df=",df,"p=",1-pchisq(x2,df),sep="\t")
+  cat("Pearson x2=",round(x2,3),", df=",df,", p=",1-pchisq(x2,df),sep="\t")
   cat("\n")
   list (allele.freq=allele.freq,x2=x2, p.x2=1-pchisq(x2,df),
         lrt=lrt, p.lrt=1-pchisq(lrt,df), df=df, rho=rho)
@@ -103,3 +103,4 @@ hwe <- function(data, data.type="allele", yates.correct=FALSE, miss.val=0)
 # 08-11-2004 debug, refer to code of August 2004 and done
 # 09-11-2004 correct allele lables for allele frequencies
 # 10-11-2004 fix lrt statistic and p.lrt
+# 16-01-2005 fix n.genotype
